@@ -4,17 +4,29 @@ import dateutil.tz
 import datetime
 from bs4 import BeautifulSoup
 from datetime import timedelta
+from enum import IntEnum
 
 # Global
 TATORT_URL = "https://www.daserste.de/unterhaltung/krimi/tatort/vorschau/index.html"
 
 
-def get_tatort() -> [dict]:
+class Scheduletype(IntEnum):
+    Erste = 1
+    Dritte = 2
+
+
+def get_tatort_erste() -> [dict]:
     """
-    Returns the current schedule for Tatort.
+    Returns the current schedule for Tatort on the channel "Das Erste".
     """
-    website = load_tatort_website()
-    return parse_tatort_website(website)
+    return parse_tatort_website(load_tatort_website(), Scheduletype.Erste)
+
+
+def get_tatort_dritte() -> [dict]:
+    """
+    Returns the current schedule for Tatort on other channels.
+    """
+    return parse_tatort_website(load_tatort_website(), Scheduletype.Dritte)
 
 
 def load_tatort_website() -> str:
@@ -27,7 +39,7 @@ def load_tatort_website() -> str:
     return html_file
 
 
-def parse_tatort_website(html: str) -> [dict]:
+def parse_tatort_website(html: str, schedule=Scheduletype.Erste) -> [dict]:
     """
     Parses the given Tatort website and returns an array of dicts, each
     containing a schedule entry for the upcoming Tatort episodes.
@@ -36,18 +48,13 @@ def parse_tatort_website(html: str) -> [dict]:
     >>> schedule = parse_tatort_website(site)
     >>> schedule[0]
     {'title': 'Rettung so nah', 'city': 'Dresden', 'inspectors': 'Gorniak, Winkler und Schnabel', 'time': '2021-02-07T20:15:00+01:00', 'link': 'https://www.daserste.de/unterhaltung/krimi/tatort/sendung/rettung-so-nah-100.html'}
+    >>> schedule = parse_tatort_website(site, Scheduletype.Dritte)
+    >>> schedule[0]
+    {'title': 'Ein FuÃŸ kommt selten allein', 'city': 'MÃ¼nster', 'inspectors': 'Thiel und Boerne', 'channel': 'BR', 'time': '2021-02-09T20:15:00+01:00', 'link': 'https://www.daserste.de/unterhaltung/krimi/tatort/sendung/ein-fuss-kommt-selten-allein-104.html'}
     """
     soup = BeautifulSoup(html, "html.parser")
 
-    # Found linklists:
-    # 0:"nächste Erstausstrahlung"
-    # 1:"im Ersten"
-    # 2:"in den Dritten"
-    # 3:"auf ONE"
-    # 4:"Tatort in Ihrem dritten Programm"
-    tatort_linklists = soup.find_all("div", class_="linklist")
-
-    # Timestamp of website request is between </body> and </html> tag:
+    # Timestamp of website request is between </body> and </html> tag, e.g.
     # </body><!-- stage-4.deo @ Sun Feb 07 09:16:08 CET 2021 --></html>
     for line in reversed(soup.html.contents):
         at_index = line.find("@")  # look for comment
@@ -65,10 +72,17 @@ def parse_tatort_website(html: str) -> [dict]:
     except Exception as e:
         request_timestamp = datetime.now()
 
-    tatort_im_ersten_list = tatort_linklists[1].find_all("a")
+    # Found linklists:
+    # 0:"nächste Erstausstrahlung"
+    # 1:"im Ersten"
+    # 2:"in den Dritten"
+    # 3:"auf ONE"
+    # 4:"Tatort in Ihrem dritten Programm"
+    tatort_linklists = soup.find_all("div", class_="linklist")
+    tatort_list = tatort_linklists[int(schedule)].find_all("a")
     schedule_list = []
-    for link in tatort_im_ersten_list:
-        entry = _parse_row(link.string, request_timestamp)
+    for link in tatort_list:
+        entry = _parse_row(link.string, request_timestamp, schedule)
         entry["link"] = link["href"]
         if not "https://www.daserste.de" in entry["link"]:
             entry["link"] = "https://www.daserste.de" + entry["link"]
@@ -76,14 +90,14 @@ def parse_tatort_website(html: str) -> [dict]:
     return schedule_list
 
 
-def _parse_row(schedule_text: str, request_timestamp: datetime.datetime) -> dict:
+def _parse_row(schedule_text: str, request_timestamp: datetime.datetime, schedule: Scheduletype) -> dict:
     """
     Parses a row in the Tatort schedule, for example:
     >>> entry_string = "So., 14.02. | 20:15 Uhr | Hetzjagd (Odenthal und Stern  (Ludwigshafen))"
 
     A request timestamp has to be passed into the function, because the first column can contain 'Heute' or 'Morgen' (today and tomorrow respectively)
     >>> request_ts = datetime.datetime(2021, 2, 7, 9, 16, 8, 0, dateutil.tz.gettz('Europe/Berlin'))
-    >>> entry = _parse_row(entry_string, request_ts)
+    >>> entry = _parse_row(entry_string, request_ts, Scheduletype.Erste)
 
     The results are returned in a dictionary:
     >>> entry["time"]
@@ -94,9 +108,27 @@ def _parse_row(schedule_text: str, request_timestamp: datetime.datetime) -> dict
     'Ludwigshafen'
     >>> entry["inspectors"]
     'Odenthal und Stern'
+
+    >>> entry_string = "Di., 09.02. | 20:15 Uhr | BR | Ein Fuß kommt selten allein (Thiel und Boerne  (Münster))"
+    >>> entry = _parse_row(entry_string, request_ts, Scheduletype.Dritte)
+    >>> entry["time"]
+    '2021-02-09T20:15:00+01:00'
+    >>> entry["title"]
+    'Ein Fuß kommt selten allein'
+    >>> entry["city"]
+    'Münster'
+    >>> entry["inspectors"]
+    'Thiel und Boerne'
+    >>> entry["channel"]
+    'BR'
     """
     columns = schedule_text.split(" | ")
-    entry = _parse_title(columns[2])
+
+    if schedule == Scheduletype.Erste:
+        entry = _parse_title(columns[2])
+    elif schedule == Scheduletype.Dritte:
+        entry = _parse_title(columns[3])
+        entry["channel"] = columns[2]
     entry["time"] = _parse_datetime(columns[0], columns[1], request_timestamp)
     return entry
 
